aboutsummaryrefslogtreecommitdiffstats
path: root/src/libutil/http.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/libutil/http.h')
-rw-r--r--src/libutil/http.h11
1 files changed, 10 insertions, 1 deletions
diff --git a/src/libutil/http.h b/src/libutil/http.h
index 23d2fa3fa..8da1bf5e0 100644
--- a/src/libutil/http.h
+++ b/src/libutil/http.h
@@ -378,7 +378,7 @@ gboolean rspamd_http_message_append_body (struct rspamd_http_message *msg,
const gchar *data, gsize len);
/**
* Append a header to reply
* @param rep
* @param name
* @param value
@@ -387,6 +387,15 @@ void rspamd_http_message_add_header (struct rspamd_http_message *msg,
const gchar *name,
const gchar *value);
+void rspamd_http_message_add_header_len (struct rspamd_http_message *msg,
+ const gchar *name,
+ const gchar *value,
+ gsize len);
+
+void rspamd_http_message_add_header_fstr (struct rspamd_http_message *msg,
+ const gchar *name,
+ rspamd_fstring_t *value);
+
/**
* Search for a specified header in message
* @param msg message
@@ -378,7 +378,7 @@ gboolean rspamd_http_message_append_body (struct rspamd_http_message *msg,
const gchar *data, gsize len);
/**
- * Append a header to reply
+ * Append a header to http message
* @param rep
* @param name